from setuptools import setup

setup(name='ftThanos',
version="0.0.81",
description="A client for 81 API",
author="Thanos 81",
author_email="thanos@81paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
